# MACE: MetAl Complexes Embedding

Python library (beta-version) and command-line tool (under development) for generation of 3D coordinates for complexes of d-/f-elements.

For more details including usage examples see the [GitHub page](https://github.com/EPiCs-group/mace).


## Installation

Create new conda environment with [RDKit](http://anaconda.org/rdkit/rdkit) 2020.03.1 or later:

```
> conda create -n mace
> conda install -c rdkit rdkit=2020.09.1
```

Next, activate the environment and install [epic-mace](https://pypi.org/project/epic-mace) package using pip:

```
> conda activate mace
> pip install epic-mace
```

Enjoy!

